==> haskell-prim-uniq-0.2-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-3GVdimBseF93RrJtfLDuTL
key:                  prim-uniq-0.2-3GVdimBseF93RrJtfLDuTL
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  fc24151a080b5d031fe991eac168f444
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.0.2/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-3GVdimBseF93RrJtfLDuTL
depends:
    base-4.15.1.0 dependent-sum-0.7.2.0-3YfGnK7zBc22YESpnXzWLr
    primitive-0.7.4.0-FQ4eDy3eAyCDsbsfdb3vaO

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prim-uniq-0.2-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-CFSblP7TrZVD8q0NOaw4g7
key:                  prim-uniq-0.2-CFSblP7TrZVD8q0NOaw4g7
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  d16ed072e53d73ffcacbc312cc129793
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.0.2/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-CFSblP7TrZVD8q0NOaw4g7
depends:
    base-4.15.1.0 dependent-sum-0.7.2.0-4JnKZV2KxML90XzeSSeGDE
    primitive-0.7.4.0-JO2L1m8yKpKHqM3qF2iOEl

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
